
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.4rc2',
    'branch_nick': 'patch-0-Release__1_20_4rc2_preparation',
    'revision_id': '5fc76107eae39f97ffbcb83400ab8844f7b5f7a5',
    'revno': 8427
}
